@@ -114,7 +114,8 @@ template = """
       </tbody>
     </table>
     <script type="text/javascript">
-      addLoadEvent(${optrans_name}.init(${form_reference}))
+      var form_reference = $('${optrans_name}_btn_available').form;
+      addLoadEvent(${optrans_name}.init(form_reference))
     </script>
 </div>
 """
@@ -181,7 +182,7 @@ class SelectShuttle(widgets.CompoundFormField):
     selected_removed = widgets.HiddenField('selected_removed',
                                            validator=ShuttleParser())
 
-    params = ["title_available", "title_selected", "form_reference",
+    params = ["title_available", "title_selected", 
               "btn_all_selected", "btn_all_available",
               "btn_to_selected", "btn_to_available",
               "available_options",
@@ -190,7 +191,6 @@ class SelectShuttle(widgets.CompoundFormField):
     params_doc = {
         'title_available':'Header for available options',
         'title_selected':'Header for selected options',
-        'form_reference':'Form number on the page, if in a multi-form page',
         'btn_all_selected':'Text to the button that moves all available to selected',
         'btn_all_available':'Text to the button that moves all selected to available',
         'btn_to_selected':'Text to the button that moves one available option to selected',
@@ -208,7 +208,6 @@ class SelectShuttle(widgets.CompoundFormField):
 
     title_available = "Left"
     title_selected = "Right"
-    form_reference = 'document.forms[0]'
     btn_to_selected = '>>'
     btn_all_selected = 'All >>'
     btn_all_available = '<< All'
@@ -280,7 +279,6 @@ class SelectShuttleDesc(WidgetDescription):
         label = "The shuttle",
         title_available = "Available options",
         title_selected = "Selected options",
-        form_reference = "document.forms['%s']" % form_name,
         # All data should be provided as a list of tuples, in the form of
         # ("id", "value"). ATM, id should be an int
         available_options = [(i, "Option %d"%i) for i in xrange(5)],
